@@ -1,7 +1,7 @@
 """
 napari-STPT reads zarr files and displays them
 """
-import sys
+# import sys
 
 try:
     from napari_stpt.napari_stpt import NapariSTPT
@@ -9,8 +9,8 @@ except:
     from napari_stpt import NapariSTPT
 
 def main():
-    nap = NapariSTPT()
-    nap.main()
+    napari = NapariSTPT()
+    napari.main()
 
 if __name__ == "__main__":
     main()
\ No newline at end of file
